
#ifndef __PARSE_H__
#define __PARSE_H__



#define TRUE                 1
#define FALSE                0

#define NO_MESSAGE          -1

#define NUM_CHANNEL         12                           /* Maximum number of Channels     */
#define NUM_MESSAGE          2                           /* Maximum number of Messages     */
#define IN_BUF_LEN        2048                           /* Maximum length of Input Buffer */
#define MESSAGE_LEN       2048                           /* Maximum length of a message    */




/****************************** Beginning of Message Structures ****************************/

/* Structures for POSITION_DATA */
typedef struct _TIME_ {
	int Hour, Minute, Second;
} TIME;

typedef struct _DATE_ {
	int Year, Month, Day;
} _DATE;

typedef struct _POSITION_ {
	long Latitude, Longitude, Alt_gps, Alt_msl;
} _POSITION;

typedef struct _VELOCITY_ {
	unsigned int G_velocity;
	int          Track_angle;
} VELOCITY;

typedef struct _DOP_ {
	int Type, Value;
} DOP;

typedef struct _CHANNEL_ {
	int SV_ID, Track_mode, Pos_fix, Unhealthy, Not_using_channel, Signal_strength;
} CHANNEL;

typedef struct _RECEIVER_STATUS_ {
	int Fix_mode, Poor_geo, ThreeD_fix, Alt_hold, Diff, Insufficient_VS, Bad_almanac;
} RECEIVER_STATUS;





/* Position/Time/Status Message */
typedef struct _POSITION_DATA_ {
	TIME            Time;
	_DATE           Date;
	_POSITION       Position;
	VELOCITY        Velocity;
	DOP             Dop;
	int             Track_SV;
	int             Visible_SV;
	CHANNEL         Channel[12];
	RECEIVER_STATUS Receiver;
} POSITION_DATA;





/* Structure for VSS_DATA */
typedef struct _VSS_ {
	int Sat_id,			/* Each satellite's ID */
		Healthy,		/* Healthy             */
		Doppler,		/* Doppler             */
		Elevation,		/* Elevation           */
		Azimuth ;		/* Azimuth             */
} VSS;



/* Visible Satellite Status Message */

typedef struct _VSS_DATA {
	int Total_sat_num;                               /* Total number of visible satellites      */
	VSS Visible_sat[NUM_CHANNEL];                    /* Array of visible satellites             */
} VSS_DATA;


/****************************** End of Message Structures **********************************/







/* NBIP Message */
enum MESSAGE 
{ 
	Position_Time_Status_Request,      
	Visible_Satellites_Status_Messge_Request    
};


/* External variables */
extern VSS_DATA       Vss_data;                      /* Visible satellites status data             */
extern POSITION_DATA  Position_data;                 /* Position data                              */

/* External functions */
extern int  NBIP_parse_buf(unsigned char *buf, int len);      /* Parse buf and contstruct message structure */

#endif
